diff --git a/doc/src/sgml/textsearch.sgml b/doc/src/sgml/textsearch.sgml
index 82afe20..d1ae7b7 100644
--- a/doc/src/sgml/textsearch.sgml
+++ b/doc/src/sgml/textsearch.sgml
@@ -3034,15 +3034,17 @@ CREATE TEXT SEARCH DICTIONARY english_stem (
    <title>Dictionaries in Shared Memory</title>
 
    <para>
-    Some dictionaries, especially <application>Ispell</application>, consumes a
-    noticable value of memory.  Size of a dictionary can reach tens of megabytes.
-    Most of them also stores configuration in text files.  A dictionary is compiled
-    during first access per a user session.
+    Some dictionaries, especially <application>Ispell</application>, consumes
+    a significant amount of memory, in some cases tens of megabytes.  Most of
+    them store the data in text files, and building the in-memory structure is
+    both CPU and time-consuming.  Instead of doing this in each backend when
+    it needs a dictionary for the first time, the compiled dictionary may be
+    stored in shared memory so that it may be reused by other backends.
    </para>
 
    <para>
-    To store dictionaries in shared memory set to <xref linkend="guc-max-shared-dictionaries-size"/>
-    parameter value greater than zero before server starting.
+    To enable storing dictionaries in shared memory, set <xref linkend="guc-max-shared-dictionaries-size"/>
+    parameter to a value greater than zero.
    </para>
 
   </sect2>
diff --git a/src/backend/tsearch/dict_ispell.c b/src/backend/tsearch/dict_ispell.c
index f8ab16d..43aa27a 100644
--- a/src/backend/tsearch/dict_ispell.c
+++ b/src/backend/tsearch/dict_ispell.c
@@ -5,14 +5,14 @@
  *
  * Portions Copyright (c) 1996-2018, PostgreSQL Global Development Group
  *
- * By default all Ispell dictionaries are stored in DSM. But if number of
- * loaded dictionaries reached maximum allowed value then it will be
- * allocated within its memory context (dictCtx).
+ * By default all Ispell dictionaries are stored in DSM. But if the amount
+ * of memory exceeds max_shared_dictionaries_size, then the dictionary be
+ * allocated in private backend memory (in dictCtx context).
  *
  * All necessary data are built within dispell_build() function. But
  * structures for regular expressions are compiled on first demand and
  * stored using AffixReg array. It is because regex_t and Regis cannot be
- * stored in shared memory.
+ * stored in shared memory easily.
  *
  *
  * IDENTIFICATION
